pyrasa.utils.peak\_utils.get\_band\_info
========================================

.. currentmodule:: pyrasa.utils.peak_utils

.. autofunction:: get_band_info

.. _sphx_glr_backreferences_pyrasa.utils.peak_utils.get_band_info:

.. minigallery:: pyrasa.utils.peak_utils.get_band_info
    :add-heading: